@@ -46,4 +46,6 @@ class PutPolicy(object):
         if cfg.detectNotifyRule:
             self.set_conf('detectNotifyRule', str(cfg.detectNotifyRule))
         if cfg.hashAlgorithm:
-            self.set_conf('hashAlgorithm', str(cfg.hashAlgorithm))
\ No newline at end of file
+            self.set_conf('hashAlgorithm', str(cfg.hashAlgorithm))
+        if cfg.deadline:
+            self.set_conf('deadline', str(cfg.deadline))
